==> openpy_fxts-0.1.2-py3-none-any.whl: openpy_fxts-0.1.2.dist-info/LICENSE.md <==
# OpenPy_FXTS
OpenPy_FXTS is an application for forecasting for Time Series, developed within the OpenREiD project (Integral software for simulation and optimization of electrical distribution networks), of the Instituto de Energía Eléctrica (IEE), UNSJ - CONICET, San Juan - Argentina. 

## Version 0.1.0
This first beta version allows to performance state estimation in single-phase distribution systems with nonlinear methods with and without phasor and linear measurements. In the case of multiphase networks, the positive sequence equivalent is obtained and the estimated state is obtained with a nonlinear method with or without phasor measurements. 

## Source Code
All the source code of the OpenPy_FXTS tool is accessible and distributed compressed in ZIP and is available in the GitHub and SourceForge repositories.

## Third-Party Components
+ Python Version: 3.9 (x64) License: Python Software Foundation License. 
+ Python Plugins, Supported Versions, and Opensource Licenses. 

## System Requirements

- Microsoft Windows 10-64bit.
- Pentium compatible PC (Intel Core i5 or higher).
- 2 GB RAM (4 GB RAM recommended).
- At least 4 GB available on the hard disk.

## License
Shield: [![CC BY-NC-SA 4.0][cc-by-nc-sa-shield]][cc-by-nc-sa]

This work is licensed under a
[Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License][cc-by-nc-sa].

[![CC BY-NC-SA 4.0][cc-by-nc-sa-image]][cc-by-nc-sa]

[cc-by-nc-sa]: http://creativecommons.org/licenses/by-nc-sa/4.0/
[cc-by-nc-sa-image]: https://licensebuttons.net/l/by-nc-sa/4.0/88x31.png
[cc-by-nc-sa-shield]: https://img.shields.io/badge/License-CC%20BY--NC--SA%204.0-lightgrey.svg

## Disclaimer of Warranties and Limitation of Liability 

This software tool is provided by the Instituto de Energía Eléctrica (IEE), UNSJ - CONICET, on an "as is" and "as available" basis and makes no representations or warranties of any kind with respect to the Licensed Material, whether express, implied, statutory or otherwise. This includes, but is not limited to, warranties of title, merchantability, fitness for a particular purpose, non-infringement, freedom from latent defects or other defects, accuracy, the presence or absence of errors, whether or not known or detectable. Where a disclaimer of warranties, in whole or in part, is not permitted, this exclusion may not apply to you.
In no event shall the Instituto de Energía Eléctrica (IEE), UNSJ - CONICET, be liable for any direct, indirect, incidental, special, exemplary, or consequential damages (including, without limitation, procurement of substitute goods or services; loss of use, data or profits; or business interruption) however arising and on any theory of liability, whether in contract, strict liability or tort (including negligence or otherwise) arising in any way out of the use of this software, even if advised of the possibility of such damages.
For further details on the disclaimer of warranties and limitation of liability referred to the license terms.

## Credits 
* Developer: Jorge A. Lara S.
* Director: Mauricio E. Samper
* Co-Director: D. Graciela Colomé

==> openpy_fxts-0.2.3-py3-none-any.whl: openpy_fxts-0.2.3.dist-info/LICENSE.md <==
# OpenPy-FXTS
OpenPy-FXTS is an application for  Forecasting and imputation for time series data, developed within the OpenREiD project (Integral software for simulation and optimization of electrical distribution networks), of the Instituto de Energía Eléctrica (IEE), UNSJ - CONICET, San Juan - Argentina. 

## Version 0.1.5
This first beta version allows to performance state estimation in single-phase distribution systems with nonlinear methods with and without phasor and linear measurements. In the case of multiphase networks, the positive sequence equivalent is obtained and the estimated state is obtained with a nonlinear method with or without phasor measurements. 

## Source Code
All the source code of the OpenPy-FXTS tool is accessible and distributed compressed in ZIP and is available in the GitHub and SourceForge repositories.

## Third-Party Components
+ Python Version: 3.11 (x64) License: Python Software Foundation License. 
+ Python Plugins, Supported Versions, and Opensource Licenses. 

## System Requirements

- Microsoft Windows 10-64bit.
- Pentium compatible PC (Intel Core i5 or higher).
- 2 GB RAM (4 GB RAM recommended).
- At least 4 GB available on the hard disk.

## License
Shield: [![CC BY-NC-SA 4.0][cc-by-nc-sa-shield]][cc-by-nc-sa]

This work is licensed under a
[Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License][cc-by-nc-sa].

[![CC BY-NC-SA 4.0][cc-by-nc-sa-image]][cc-by-nc-sa]

[cc-by-nc-sa]: http://creativecommons.org/licenses/by-nc-sa/4.0/
[cc-by-nc-sa-image]: https://licensebuttons.net/l/by-nc-sa/4.0/88x31.png
[cc-by-nc-sa-shield]: https://img.shields.io/badge/License-CC%20BY--NC--SA%204.0-lightgrey.svg

## Disclaimer of Warranties and Limitation of Liability 

This software tool is provided by the Instituto de Energía Eléctrica (IEE), UNSJ - CONICET, on an "as is" and "as available" basis and makes no representations or warranties of any kind with respect to the Licensed Material, whether express, implied, statutory or otherwise. This includes, but is not limited to, warranties of title, merchantability, fitness for a particular purpose, non-infringement, freedom from latent defects or other defects, accuracy, the presence or absence of errors, whether or not known or detectable. Where a disclaimer of warranties, in whole or in part, is not permitted, this exclusion may not apply to you.
In no event shall the Instituto de Energía Eléctrica (IEE), UNSJ - CONICET, be liable for any direct, indirect, incidental, special, exemplary, or consequential damages (including, without limitation, procurement of substitute goods or services; loss of use, data or profits; or business interruption) however arising and on any theory of liability, whether in contract, strict liability or tort (including negligence or otherwise) arising in any way out of the use of this software, even if advised of the possibility of such damages.
For further details on the disclaimer of warranties and limitation of liability referred to the license terms.

## Credits 
* Developer: Jorge A. Lara S.
* Supervision: Mauricio E. Samper
